==> healthrian_visualization_support-1.0.13.tar.gz: lib/src/widgets/wear_cardio_t/oxi_weart.dart <==
// ignore_for_file: public_member_api_docs

import 'package:copy_with_extension/copy_with_extension.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_support/healthrian_ble_support.dart';
import 'package:healthrian_visualization_support/'
    'healthrian_visualization_support.dart';

part 'oxi_weart.g.dart';

@CopyWith()
class OxiWearT extends StatelessWidget {
  const OxiWearT({
    super.key,
    this.onLoadingWidget,
    this.height = 200,
    this.colors = const [
      Colors.blue,
      Colors.green,
    ],
    this.measureTime = 15,
  });

  final int measureTime;
  final List<Color> colors;
  final double height;
  final Widget? onLoadingWidget;

  @override
  Widget build(BuildContext context) {
    final streams = BLEManager().manageWearCardioT.streams;
    return SizedBox(
      width: MediaQuery.of(context).size.width,
      child: Observer(
        key: UniqueKey(),
        builder: (context) {
          return StreamBuilder(
            stream: streams.bufferedPlotStreamOxi,
            builder: (context, snapshot) {
              if (!snapshot.hasData) {
                return onLoadingWidget ?? const Text('No Stream');
              }
              return Column(
                children: [
                  for (var i = 0; i < snapshot.data!.length; i++)
                    SizedBox(
                      height: height,
                      child: Channel(
                        ecgSequence: snapshot.data![i],
                        color: colors[i % colors.length],
                        measureTime: measureTime,
                        samplingRate: 100,
                      ),
                    ),
                ],
              );
            },
          );
        },
      ),
    );
  }
}

==> healthrian_visualization_support-1.0.36.tar.gz: lib/src/widgets/wear_cardio_t/oxi_weart.dart <==
// ignore_for_file: public_member_api_docs

import 'package:copy_with_extension/copy_with_extension.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_support/healthrian_ble_support.dart';
import 'package:healthrian_visualization_support/'
    'healthrian_visualization_support.dart';

part 'oxi_weart.g.dart';

@CopyWith()
class OxiWearT extends StatelessWidget {
  const OxiWearT({
    super.key,
    this.onLoadingWidget,
    this.height = 200,
    this.colors = const [
      Colors.red,
      Colors.blue,
      Colors.green,
    ],
    this.measureTime = 5,
    this.backgroundColor = Colors.transparent,
    this.wrapperWidget,
  });

  final double measureTime;
  final List<Color> colors;
  final double height;
  final Widget? onLoadingWidget;
  final Color backgroundColor;

  final Widget Function(List<Widget>)? wrapperWidget;

  @override
  Widget build(BuildContext context) {
    final streams = BLEManager().manageWearCardioT.streams;
    return SizedBox(
      width: MediaQuery.of(context).size.width,
      child: Observer(
        key: UniqueKey(),
        builder: (context) {
          return StreamBuilder(
            stream: streams.bufferedPlotStreamOxi,
            builder: (context, snapshot) {
              if (!snapshot.hasData) {
                return onLoadingWidget ?? const Text('No Stream');
              }
              final r = snapshot.data!.toList();
              final children = [
                for (var i = 0; i < r.length; i++)
                  if (r[i].isNotEmpty)
                    SizedBox(
                      height: height,
                      child: ChannelWithPivot(
                        ecgSequence: r[i],
                        color: colors[i % colors.length],
                        measureTime: measureTime,
                        samplingRate: 100,
                        backgroundColor: backgroundColor,
                      ),
                    ),
              ];

              if (wrapperWidget == null) {
                return Column(
                  children: children,
                );
              }
              return wrapperWidget!(children);
            },
          );
        },
      ),
    );
  }
}
